@@ -1,12 +1,7 @@
-mod serde_skin;
 mod serde_compound_style;
 mod serde_line_style;
 mod serde_scrollbar_style;
+mod serde_skin;
 mod serde_styled_char;
 
-pub use {
-    serde_scrollbar_style::*,
-};
-
-
-
+pub use serde_scrollbar_style::*;
